import { InjectionToken } from '@angular/core';
import { TranslocoTranspiler } from '@ngneat/transloco';
import { TranslationMarkupRendererFactory } from '../translation-markup-renderer-factory';
import { TokenizeResult, TranslationMarkupTranspiler, TranspileResult, TranslationMarkupTranspilerContext } from '../translation-markup-transpiler.model';
/**
 * Interface for objects that can detect interpolation expressions.
 */
export interface InterpolationExpressionMatcher {
    /**
     * Checks whether an interpolation expression is found in the given string at the specified offset.
     *
     * @param   source String where the interpolation expression might be found.
     * @param   offset Position within the string which should be checked for the presence of an interpolation expression.
     * @returns        Length of the interpolation expression in number of characters or `undefined` if no expression was found.
     */
    matchExpression(source: string, offset: number): number | undefined;
}
/**
 * Interpolation expression matcher for the default syntax of Transloco interpolation expressions: `{{...}}`.
 *
 * @param   translationValue String where the interpolation expression might be found.
 * @param   offset           Position within the string which should be checked for the presence of an interpolation expression.
 * @returns                  The length of the interpolation expression in number of characters or `undefined` if none was found.
 */
export declare function defaultTranslationInterpolationExpressionMatcher(translationValue: string, offset: number): number | undefined;
/**
 * Factory function for the `defaultTranslationInterpolationExpressionMatcher`. Used for the `TRANSLATION_INTERPOLATION_EXPRESSION_MATCHER`
 * injection token.
 */
export declare function defaultTranslationInterpolationExpressionMatcherFactory(): InterpolationExpressionMatcher;
/**
 * Injection token that is used for defining the provider for the `InterpolationExpressionMatcher`, which is needed by the
 * `StringInterpolationTranspiler`.
 */
export declare const TRANSLATION_INTERPOLATION_EXPRESSION_MATCHER: InjectionToken<InterpolationExpressionMatcher>;
/**
 * Markup transpiler that supports interpolation expressions, and which creates a renderer that expands the expression to string using the
 * `TranslocoTranspiler`. Since the `TranslocoTranspiler` can be overridden with a custom implementation that uses a different syntax this
 * class uses a (configurable) `InterpolationExpressionMatcher`. This expression matcher can be overridden with a different implementation
 * that supports the syntax of a custom `TranslocoTranspiler`.
 */
export declare class StringInterpolationTranspiler implements TranslationMarkupTranspiler {
    /** Renderer factory which will be used for rendering the text nodes containing the result of interpolation expressions. */
    private readonly rendererFactory;
    /** The Transloco transpiler that will be used for evaluating interpolation expressions. */
    private readonly translocoTranspiler;
    /** Matcher that can find interpolation expressions in a translation value which are supported by the Transloco transpiler. */
    private readonly expressionMatcher;
    /**
     * Creates a new `StringInterpolationTranspiler` that uses the specified renderer factory, Transloco transpiler and expression matcher.
     */
    constructor(
    /** Renderer factory which will be used for rendering the text nodes containing the result of interpolation expressions. */
    rendererFactory: TranslationMarkupRendererFactory, 
    /** The Transloco transpiler that will be used for evaluating interpolation expressions. */
    translocoTranspiler: TranslocoTranspiler, 
    /** Matcher that can find interpolation expressions in a translation value which are supported by the Transloco transpiler. */
    expressionMatcher: InterpolationExpressionMatcher);
    /** @inheritdoc */
    tokenize(translation: string, offset: number): TokenizeResult | undefined;
    /** @inheritdoc */
    transpile(tokens: unknown[], offset: number, { translation }: TranslationMarkupTranspilerContext): TranspileResult | undefined;
}
/**
 * Token class for interpolation expressions.
 */
export declare class StringInterpolationSegment {
    readonly interpolationExpression: string;
    /**
     *  Creates a new `StringInterpolationSegment` for the specified expression.
     */
    constructor(interpolationExpression: string);
}
